<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('RefCerobong', function (Blueprint $table) {
            $table->increments('RefCerobongId');
            $table->unsignedInteger('PerusahaanId');
            $table->string('Kode', 45)->nullable();
            $table->string('Nama', 255)->nullable();
            $table->string('SumberEmisi', 255)->nullable();
            $table->string('JenisBahanBakar', 255)->nullable();
            $table->string('Konsumsi', 255)->nullable();
            $table->string('Bentuk', 255)->nullable();
            $table->float('Tinggi')->nullable();
            $table->float('Diameter')->nullable();
            $table->float('Posisi')->nullable();
            $table->string('JenisPengendali', 255)->nullable();
            $table->integer('JamOperasional')->nullable();
            // Karena Laravel tidak mendukung tipe SET, gunakan ENUM sebagai gantinya
            $table->enum('Del', ['y', 'n']);
            $table->float('Kapasitas')->nullable();
            $table->string('SatuanKapasitas', 255)->nullable();
            $table->double('Lintang')->nullable()->comment('lintang in decimal degree');
            $table->double('Bujur')->nullable()->comment('bujur in decimal degree');

            // Membuat index untuk kolom PerusahaanId
            $table->index('PerusahaanId', 'Indexing_PerusahaanId');

            // Menambahkan foreign key untuk relasi dengan tabel Perusahaan
            $table->foreign('PerusahaanId')
                  ->references('PerusahaanId')
                  ->on('Perusahaan')
                  ->onDelete('cascade');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('RefCerobong', function (Blueprint $table) {
            $table->dropForeign(['PerusahaanId']);
        });
        Schema::dropIfExists('RefCerobong');
    }
};
