<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('IpalParameter', function (Blueprint $table) {
            $table->id('IpalParameterId');
            $table->unsignedInteger('IpalId');
            $table->unsignedInteger('RefIpalParameterId');
            $table->string('Nama', 255);
            $table->string('Satuan', 255);
            // Menggunakan enum sebagai pengganti tipe SET
            $table->enum('BakuMutuJenis', ['Angka Tunggal', 'Rentang Angka', 'Positif/Negatif', 'Tanpa Baku Mutu'])->nullable();
            $table->string('BakuMutuNilai1', 45);
            $table->string('BakuMutuNilai2', 45)->nullable();
            $table->float('BatasEmisi', 14, 8)->nullable();

            $table->index('IpalId', 'IndexIpal_IpalId');
            $table->index('RefIpalParameterId', 'IndexRefIpalParameter_RefIpalParameterId');

            // Foreign key untuk relasi
            $table->foreign('IpalId')
                  ->references('IpalId')
                  ->on('Ipal')
                  ->onDelete('cascade');

            $table->foreign('RefIpalParameterId')
                  ->references('RefIpalParameterId')
                  ->on('RefIpalParameter')
                  ->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('IpalParameter', function (Blueprint $table) {
            $table->dropForeign(['IpalId']);
            $table->dropForeign(['RefIpalParameterId']);
        });
        Schema::dropIfExists('IpalParameter');
    }
};
