<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('HasilUjiBS', function (Blueprint $table) {
            $table->increments('HasilUjiBSId');
            $table->unsignedInteger('PelaporanId');
            $table->unsignedInteger('LokasiId');
            $table->string('Nama', 255);
            $table->double('Lintang')->nullable()->comment('lintang in decimal degree');
            $table->double('Bujur')->nullable()->comment('lintang in decimal degree');
            // Menggunakan ENUM sebagai pengganti tipe SET
            $table->enum('BakuMutuJenis', ['Angka Tunggal', 'Rentang Angka', 'Positif/Negatif']);
            $table->string('BakuMutuNilai1', 45);
            $table->string('BakuMutuNilai2', 45)->nullable();
            $table->string('HasilUji', 45)->nullable();

            $table->index('PelaporanId', 'IndexHasilUjiBS_PelaporanId');
            $table->index('LokasiId', 'Index_LokasiId');

            $table->foreign('PelaporanId')
                  ->references('PelaporanId')
                  ->on('Pelaporan')
                  ->onDelete('cascade');

            $table->foreign('LokasiId')
                  ->references('LokasiId')
                  ->on('Lokasi')
                  ->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('HasilUjiBS', function (Blueprint $table) {
            $table->dropForeign(['PelaporanId']);
            $table->dropForeign(['LokasiId']);
        });
        Schema::dropIfExists('HasilUjiBS');
    }
};
