<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('HasilUjiLP', function (Blueprint $table) {
            $table->id('HasilUjiLPId');
            $table->unsignedInteger('PelaporanId');
            $table->integer('Tahun');
            $table->unsignedInteger('PerusahaanId');
            $table->enum('Sampah', [
                'Volume Timbulan Sampah',
                'Volume Pengolahan Sampah',
                'Volume Sampah Diangkut'
            ]);
            $table->enum('Jenis', [
                '',
                'Organik',
                'Anorganik',
                'Mudah Terurai',
                'Daur Ulang',
                'Residu'
            ])->default('');
            $table->string('Bulan', 100);
            $table->float('Nilai');

            $table->index('PelaporanId', 'IndexHasilUjiPL_PelaporanId');
            $table->index('PerusahaanId', 'IndexHasilUjiPL_PerusahaanId');

            // Menambahkan foreign key (pastikan tabel Pelaporan dan Perusahaan sudah ada)
            $table->foreign('PelaporanId')
                  ->references('PelaporanId')
                  ->on('Pelaporan')
                  ->onDelete('cascade');

            $table->foreign('PerusahaanId')
                  ->references('PerusahaanId')
                  ->on('Perusahaan')
                  ->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('HasilUjiLP', function (Blueprint $table) {
            $table->dropForeign(['PelaporanId']);
            $table->dropForeign(['PerusahaanId']);
        });
        Schema::dropIfExists('HasilUjiLP');
    }
};
