<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('NilaiKomponen', function (Blueprint $table) {
            $table->id('NilaiKomponenId');
            $table->unsignedInteger('PelaporanId');
            $table->unsignedInteger('KomponenId');
            $table->unsignedInteger('HasilId');
            $table->float('Nilai')->nullable();
            $table->tinyInteger('Verifikasi')->nullable();
            $table->dateTime('TanggalVerifikasi')->nullable();
            $table->text('Catatan')->nullable();
            $table->text('Keterangan')->nullable();
            $table->unsignedInteger('Verifikator')->nullable();
            $table->unsignedInteger('IpalId')->nullable();
            $table->unsignedInteger('CerobongId')->nullable();

            $table->index('PelaporanId', 'IndexNilaiKomponen_PelaporanId');
            $table->index('KomponenId', 'IndexNilaiKomponen_KomponenId');

            // Foreign key constraints (pastikan tabel yang dirujuk sudah ada)
            $table->foreign('PelaporanId')
                  ->references('PelaporanId')
                  ->on('Pelaporan')
                  ->onDelete('cascade');

            $table->foreign('KomponenId')
                  ->references('KomponenId')
                  ->on('Komponen')
                  ->onDelete('cascade');

            $table->foreign('HasilId')
                  ->references('HasilId')
                  ->on('Hasil')
                  ->onDelete('cascade');

            $table->foreign('IpalId')
                  ->references('IpalId')
                  ->on('Ipal')
                  ->onDelete('cascade');

            $table->foreign('CerobongId')
                  ->references('CerobongId')
                  ->on('Cerobong')
                  ->onDelete('cascade');
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('NilaiKomponen', function (Blueprint $table) {
            $table->dropForeign(['PelaporanId']);
            $table->dropForeign(['KomponenId']);
            $table->dropForeign(['HasilId']);
            $table->dropForeign(['IpalId']);
            $table->dropForeign(['CerobongId']);
        });
        Schema::dropIfExists('NilaiKomponen');
    }
};
