<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('NilaiKomponenPihakKetiga', function (Blueprint $table) {
            $table->id('NilaiKomponenPihakKetigaId');
            $table->unsignedInteger('NilaiKomponenId')->nullable()->comment('id dari nilai komponen');
            $table->string('Nama', 255)->nullable()->comment('nama pihak ketiga');
            $table->unsignedInteger('IzinPihakKetigaId')->nullable()->comment('id dari refizin_pihakketiga, dalam bentuk json');
            $table->decimal('Jumlah', 7, 2)->unsigned()->nullable()->comment('jumlah limbah B3, max 99.999,99 ton');
            $table->tinyInteger('Satuan')->unsigned()->default(1)->comment('1=kg, 2=ton');
            $table->tinyInteger('IsDeleted')->unsigned()->default(0)->comment('0=false, 1=true');

            // Menambahkan foreign key untuk kolom NilaiKomponenId
            $table->foreign('NilaiKomponenId')
                  ->references('NilaiKomponenId')
                  ->on('NilaiKomponen')
                  ->onDelete('cascade');

            $table->foreign('IzinPihakKetigaId')
            ->references('IzinPihakKetigaId')
            ->on('IzinPihakKetiga')
            ->onDelete('cascade');

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('NilaiKomponenPihakKetiga', function (Blueprint $table) {
            $table->dropForeign(['NilaiKomponenId']);
            $table->dropForeign(['IzinPihakKetigaId']);
        });
        Schema::dropIfExists('NilaiKomponenPihakKetiga');
    }
};
