// resources/js/Pages/Index_AL_IPAL.tsx
import React, { useState } from "react";
import { Head } from "@inertiajs/react";

// Import layout
import AuthenticatedLayout from "@/layouts/authenticated-layout";

// Import komponen modal (sesuaikan path & nama filenya)
import IPALModal from "@/components/Pelaporan/AL/IPAL/ModalIPAL";
import DataPendukungModal from "@/components/Pelaporan/AL/IPAL/DataPendukungModal";
import ParameterUjiLabModal from "@/components/Pelaporan/AL/IPAL/ParameterUjiLabModal";
import HasilUjiLabModal from "@/components/Pelaporan/AL/IPAL/HasilUjiLabModal";
import PersyaratanTeknisModal from "@/components/Pelaporan/AL/IPAL/PersyaratanTeknisModal";

interface IPALData {
    id: number;
    noIpal: string;
    namaIpal: string;
}

const IndexALIPAL: React.FC = () => {
    // Contoh data dummy IPAL
    const [ipals, setIpals] = useState<IPALData[]>([
        { id: 1, noIpal: "12312", namaIpal: "123123" },
        { id: 2, noIpal: "1a", namaIpal: "Nama IPAL 1a" },
        { id: 3, noIpal: "qwew", namaIpal: "wewqe" },
    ]);

    // State untuk modal
    const [openIPALModal, setOpenIPALModal] = useState(false);
    const [openDataPendukungModal, setOpenDataPendukungModal] = useState(false);
    const [openParameterUjiLabModal, setOpenParameterUjiLabModal] =
        useState(false);
    const [openHasilUjiLabModal, setOpenHasilUjiLabModal] = useState(false);
    const [openPersyaratanTeknisModal, setOpenPersyaratanTeknisModal] =
        useState(false);

    // State untuk menampung data IPAL yang sedang di-edit
    const [selectedIPAL, setSelectedIPAL] = useState<IPALData | null>(null);

    // Contoh handle tambah IPAL
    const handleAddIPAL = () => {
        setSelectedIPAL(null);
        setOpenIPALModal(true);
    };

    // Contoh handle edit IPAL
    const handleEditIPAL = (ipal: IPALData) => {
        setSelectedIPAL(ipal);
        setOpenIPALModal(true);
    };

    // Contoh handle delete IPAL
    const handleDeleteIPAL = (id: number) => {
        const filtered = ipals.filter((ipal) => ipal.id !== id);
        setIpals(filtered);
    };

    return (
        <AuthenticatedLayout header="Laporan Pengelolaan Air Limbah">
            <Head title="Laporan Pengelolaan Air Limbah" />
            <div className="p-4 space-y-4">
                <div>
                    <h1 className="text-xl font-bold">
                        Laporan Pengelolaan Air Limbah - Instalasi Pengolah Air
                        Limbah Ujicoba
                    </h1>
                    <p className="text-sm">Tahun 2023 - Periode Triwulan 1</p>
                </div>

                {/* Status Tersambung IPAL Komunal */}
                <div className="flex items-center justify-between mt-4">
                    <span className="text-sm">
                        <strong>Tersambung ke IPAL Komunal :</strong> Tidak
                    </span>
                    <button
                        onClick={handleAddIPAL}
                        className="px-3 py-2 bg-green-600 text-white rounded hover:bg-green-700"
                    >
                        Tambah IPAL
                    </button>
                </div>

                {/* Tabel IPAL */}
                <div className="overflow-x-auto bg-white rounded shadow-sm">
                    <table className="min-w-full text-sm">
                        <thead className="bg-gray-100">
                            <tr>
                                <th className="p-3 text-left">No. IPAL</th>
                                <th className="p-3 text-left">Nama IPAL</th>
                                <th className="p-3 text-left">
                                    Data Pendukung
                                </th>
                                <th className="p-3 text-left">
                                    Parameter Uji Lab
                                </th>
                                <th className="p-3 text-left">Hasil Uji Lab</th>
                                <th className="p-3 text-left">
                                    Persyaratan Teknis
                                </th>
                                <th className="p-3 text-left w-10"></th>
                            </tr>
                        </thead>
                        <tbody>
                            {ipals.map((ipal) => (
                                <tr
                                    key={ipal.id}
                                    className="border-b last:border-0"
                                >
                                    <td className="p-3">{ipal.noIpal}</td>
                                    <td className="p-3">
                                        {/* Klik nama IPAL untuk edit */}
                                        <button
                                            onClick={() => handleEditIPAL(ipal)}
                                            className="text-blue-600 hover:underline"
                                        >
                                            {ipal.namaIpal}
                                        </button>
                                    </td>
                                    <td className="p-3">
                                        <button
                                            onClick={() =>
                                                setOpenDataPendukungModal(true)
                                            }
                                            className="text-blue-600 hover:underline"
                                        >
                                            Data pendukung...
                                        </button>
                                    </td>
                                    <td className="p-3">
                                        <button
                                            onClick={() =>
                                                setOpenParameterUjiLabModal(
                                                    true
                                                )
                                            }
                                            className="text-blue-600 hover:underline"
                                        >
                                            Parameter
                                        </button>
                                    </td>
                                    <td className="p-3">
                                        <button
                                            onClick={() =>
                                                setOpenHasilUjiLabModal(true)
                                            }
                                            className="text-blue-600 hover:underline"
                                        >
                                            Hasil Uji Lab
                                        </button>
                                    </td>
                                    <td className="p-3">
                                        <button
                                            onClick={() =>
                                                setOpenPersyaratanTeknisModal(
                                                    true
                                                )
                                            }
                                            className="text-blue-600 hover:underline"
                                        >
                                            Persyaratan Teknis
                                        </button>
                                    </td>
                                    <td className="p-3 text-right">
                                        <button
                                            onClick={() =>
                                                handleDeleteIPAL(ipal.id)
                                            }
                                            className="text-red-600 hover:text-red-800"
                                        >
                                            x
                                        </button>
                                    </td>
                                </tr>
                            ))}
                        </tbody>
                    </table>

                    <div className="p-3 text-sm text-gray-600">
                        Menampilkan {ipals.length > 0 ? 1 : 0} sampai{" "}
                        {ipals.length} dari {ipals.length} data
                    </div>
                </div>
            </div>

            {/* Modals */}
            <IPALModal
                open={openIPALModal}
                onClose={() => setOpenIPALModal(false)}
                // Contoh: data awal jika edit
                initialData={
                    selectedIPAL ? { name: selectedIPAL.namaIpal } : undefined
                }
                onSubmit={(data) => {
                    if (selectedIPAL) {
                        // Edit
                        setIpals((prev) =>
                            prev.map((p) =>
                                p.id === selectedIPAL.id
                                    ? { ...p, namaIpal: data.name }
                                    : p
                            )
                        );
                    } else {
                        // Tambah
                        const newIPAL = {
                            id: Date.now(),
                            noIpal: `Auto-${Date.now()}`,
                            namaIpal: data.name,
                        };
                        setIpals((prev) => [...prev, newIPAL]);
                    }
                }}
            />

            <DataPendukungModal
                open={openDataPendukungModal}
                onClose={() => setOpenDataPendukungModal(false)}
            />

            <ParameterUjiLabModal
                open={openParameterUjiLabModal}
                onClose={() => setOpenParameterUjiLabModal(false)}
            />

            <HasilUjiLabModal
                open={openHasilUjiLabModal}
                onClose={() => setOpenHasilUjiLabModal(false)}
            />

            <PersyaratanTeknisModal
                open={openPersyaratanTeknisModal}
                onClose={() => setOpenPersyaratanTeknisModal(false)}
            />
        </AuthenticatedLayout>
    );
};

export default IndexALIPAL;
